.. pytextseg documentation master file.

=========================
pytextseg's documentation
=========================

The pytextseg package provides functions fill() and wrap(), Unicode-aware
alternatives for those of textwrap standard module.  It also provides
classes LineBreak and GCStr, lower level interfaces for text segmentation.

.. toctree::
   :maxdepth: 3

   install
   doc
   custom
   notes
   back

